import pandas as pd

class SMA:
    """
    Initialize the SMA class with given data and period.
    
    Parameters:
        data (list or numpy array): The input data for which SMA needs to be calculated.
        period (int): The period for which SMA needs to be calculated.
    """
    
    def __init__(self, data, period):
        self.sma = None
        self.data = pd.Series(data)
        self.period = period
        if len(self.data) > self.period:
            self.calculate()
        
    def calculate(self):
        """
        Calculate the Simple Moving Average (SMA).
        """
        self.sma = self.data.rolling(self.period).mean()
        
    def add_data_point(self, data_point):
        """
        Add a new data point to the existing data and recalculate the SMA.
        
        Parameters:
            data_point (float or int): The new data point to be added.
        """
        self.data.append(data_point)
        self.data = self.data[-self.period:]
            
    def get_smavalue(self):
        """
        Returns:
            float: The calculated SMA value.
        """
        return self.sma.iloc[-1]
            



import numpy as np

class EMA:
    def __init__(self, window, data=None):
        """
        Initialize the EMA class with given data and window size.
        
        Parameters:
            data (list or numpy array): The input data for which EMA needs to be calculated.
            window (int): The size of the window for calculating EMA.
        """
        self.ema = None
        if data is None:
            data = []
        else :
            self.data = data
        self.window = window
        if len(data) > window:
            self.calculate()
    
    def calculate(self, alpha=0.2):
        """
        Calculate the Exponential Moving Average (EMA) with the given alpha (smoothing factor).
        
        Parameters:
            alpha (float, optional): The smoothing factor. Default is 0.2.
        
        Returns:
            numpy array: The calculated EMA values.
        """
        data = np.array(self.data)
        self.ema = [data[0]]  # EMA for the first data point is the same as the data point itself
        for i in range(1, len(data)):
            ema = (alpha * data[i]) + ((1 - alpha) * self.ema[-1])
            self.ema.append(ema)
        self.ema = np.array(self.ema)
    
    def add_data_point(self, new_data_point, alpha=0.2):
        """
        Add a new data point to the existing data and recalculate the EMA.
        
        Parameters:
            new_data_point (float or int): The new data point to be added.
            alpha (float, optional): The smoothing factor. Default is 0.2.
        """
        self.data.append(new_data_point)
        if self.ema is not None:
            self.calculate(alpha)

    def get_EMA(self):
        """
        Returns:
            numpy array: The calculated EMA values.
        """
        return self.ema[-1]
    



from setuptools import setup, find_packages

setup( 
        name='ilib',
        version='0.1.1',
        # packages=find_packages(exclude=['tests*']),
        packages=find_packages(),
        license='MIT',
        description='A package for various technical indicators',
        install_requires=['numpy', 'pandas'],
        author='Devin Thakker',
        author_email='devin.thakker@outlook.com',
        url='https://github.com/devthakker/ilib',
        download_url='https://github.com/devthakker/ilib/archive/refs/tags/v0.1.1.tar.gz',
        keywords=['ilib', 'technical indicators', 'finance', 'trading', 'stocks', 'crypto'],
        classifiers=[
            'Development Status :: 3 - Alpha',
            'Programming Language :: Python :: 3.7',
            'Intended Audience :: Developers',
            'License :: OSI Approved :: MIT License',
            ],
        python_requires='>=3.7'
)